@@ -1,6 +1,6 @@
 logLik.censReg <- function( object, ... ) {
 
-   result <- maxLik:::logLik.maxLik( object )
+   result <- NextMethod( logLik, object )
    attr( result, "df" ) <- sum( activePar( object ) )
 
    class( result ) <- "logLik"
